@@ -1,13 +1,14 @@
 from __future__ import annotations
 
 import ctypes
-from ctypes import pythonapi, pointer
-from typing import TypeVar, overload, Any, Tuple
+from ctypes import POINTER, Array, pointer, pythonapi
+from typing import Any, TypeVar, overload
 
 from einspect.api import Py_ssize_t
 from einspect.protocols.delayed_bind import bind_api
 from einspect.structs.deco import struct
-from einspect.structs.py_object import PyObject, PyVarObject
+from einspect.structs.py_object import Fields, PyObject, PyVarObject
+from einspect.types import ptr
 
 _VT = TypeVar("_VT")
 
@@ -22,28 +23,25 @@ class PyTupleObject(PyVarObject[tuple, None, _VT]):
     """
 
     # Size of this array is only known after creation
-    _ob_item_0: Py_ssize_t * 0
+    _ob_item_0: ptr[PyObject] * 0
 
-    @classmethod
-    def _format_fields_(cls) -> dict[str, str]:
-        return super()._format_fields_() | {
-            "ob_item": "*PyObject[]"
-        }
+    def _format_fields_(self) -> Fields:
+        return {**super()._format_fields_(), "ob_item": "Array[*PyObject]"}
 
     @overload
     @classmethod
-    def from_object(cls, obj: Tuple[_VT, ...]) -> PyTupleObject[_VT]:
+    def from_object(cls, obj: tuple[_VT, ...]) -> PyTupleObject[_VT]:
         ...
 
     @overload
     @classmethod
-    def from_object(cls, obj: Tuple[...]) -> PyTupleObject[Any]:
+    def from_object(cls, obj: tuple[...]) -> PyTupleObject[Any]:
         ...
 
     @classmethod
-    def from_object(cls, obj: Tuple[_VT, ...]) -> PyTupleObject[_VT]:
+    def from_object(cls, obj: tuple[_VT, ...]) -> PyTupleObject[_VT]:
         """Create a PyTupleObject from an object."""
-        return super(PyTupleObject, cls).from_object(obj)  # type: ignore
+        return super().from_object(obj)  # type: ignore
 
     @property
     def mem_size(self) -> int:
@@ -54,11 +52,16 @@ class PyTupleObject(PyVarObject[tuple, None, _VT]):
         return base + (int_size * self.ob_size)
 
     @property
-    def ob_item(self):
+    def ob_item(self) -> Array[ptr[PyObject]]:
         items_addr = ctypes.addressof(self._ob_item_0)
-        arr = Py_ssize_t * self.ob_size
+        arr = POINTER(PyObject) * self.ob_size
         return arr.from_address(items_addr)
 
+    @ob_item.setter
+    def ob_item(self, value: Array[ptr[PyObject]]) -> None:
+        items_addr = ctypes.addressof(self._ob_item_0)
+        ctypes.memmove(items_addr, value, ctypes.sizeof(value))
+
     @bind_api(pythonapi["PyTuple_GetItem"])
     def GetItem(self, index: int) -> pointer[PyObject[_VT, None, None]]:
         """Return the item at the given index."""
